#  FORK PYROFORK <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .get_contact_i_ds import GetContactIDs
from .get_statuses import GetStatuses
from .get_contacts import GetContacts
from .import_contacts import ImportContacts
from .delete_contacts import DeleteContacts
from .delete_by_phones import DeleteByPhones
from .block import Block
from .unblock import Unblock
from .get_blocked import GetBlocked
from .search import Search
from .resolve_username import ResolveUsername
from .get_top_peers import GetTopPeers
from .reset_top_peer_rating import ResetTopPeerRating
from .reset_saved import ResetSaved
from .get_saved import GetSaved
from .toggle_top_peers import ToggleTopPeers
from .add_contact import AddContact
from .accept_contact import AcceptContact
from .get_located import GetLocated
from .block_from_replies import BlockFromReplies
from .resolve_phone import ResolvePhone
from .export_contact_token import ExportContactToken
from .import_contact_token import ImportContactToken
from .edit_close_friends import EditCloseFriends
from .set_blocked import SetBlocked
from .get_birthdays import GetBirthdays
