#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from ..object import Object

class GiveawayLaunched(Object):
    """A service message about a giveaway started in the channel.

    Currently holds no information.
    """

    def __init__(self):
        super().__init__()
