#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from .input_media import InputMedia
from .input_media_animation import InputMediaAnimation
from .input_media_audio import InputMediaAudio
from .input_media_document import InputMediaDocument
from .input_media_photo import InputMediaPhoto
from .input_media_video import InputMediaVideo
from .input_phone_contact import InputPhoneContact
from .input_media_area import InputMediaArea
from .input_media_area_channel_post import InputMediaAreaChannelPost

__all__ = [
    "InputMedia", "InputMediaAnimation", "InputMediaAudio", "InputMediaDocument", "InputMediaPhoto", "InputMediaVideo",
    "InputPhoneContact", "InputMediaArea", "InputMediaAreaChannelPost"
]
