#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from pyrogram import raw
from ..object import Object


class InputReplyToStory(Object):
    """Contains information about a target replied story.


    Parameters:
        peer (:obj:`~pyrogram.raw.types.InputPeer`):
            An InputPeer.

        story_id (``int``):
            Unique identifier for the target story.
    """

    def __init__(
        self, *,
        peer: "raw.types.InputPeer" = None,
        story_id: int = None
    ):
        super().__init__()

        self.peer = peer
        self.story_id = story_id

    def write(self):
        return raw.types.InputReplyToStory(
            peer=self.peer,
            story_id=self.story_id
        ).write()
