#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from enum import Enum


class AutoName(Enum):
    def _generate_next_value_(self, *args):
        return self.lower()

    def __repr__(self):
        return f"pyrogram.enums.{self}"
