#  FORK PYROFORK <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .get_config import GetConfig
from .get_nearest_dc import GetNearestDc
from .get_app_update import GetAppUpdate
from .get_invite_text import GetInviteText
from .get_support import GetSupport
from .set_bot_updates_status import SetBotUpdatesStatus
from .get_cdn_config import GetCdnConfig
from .get_recent_me_urls import GetRecentMeUrls
from .get_terms_of_service_update import GetTermsOfServiceUpdate
from .accept_terms_of_service import AcceptTermsOfService
from .get_deep_link_info import GetDeepLinkInfo
from .get_app_config import GetAppConfig
from .save_app_log import SaveAppLog
from .get_passport_config import GetPassportConfig
from .get_support_name import GetSupportName
from .get_user_info import GetUserInfo
from .edit_user_info import EditUserInfo
from .get_promo_data import GetPromoData
from .hide_promo_data import HidePromoData
from .dismiss_suggestion import DismissSuggestion
from .get_countries_list import GetCountriesList
from .get_premium_promo import GetPremiumPromo
from .get_peer_colors import GetPeerColors
from .get_peer_profile_colors import GetPeerProfileColors
from .get_timezones_list import GetTimezonesList
