#  FORK PYROFORK <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .send_custom_request import SendCustomRequest
from .answer_webhook_json_query import AnswerWebhookJSONQuery
from .set_bot_commands import SetBotCommands
from .reset_bot_commands import ResetBotCommands
from .get_bot_commands import GetBotCommands
from .set_bot_menu_button import SetBotMenuButton
from .get_bot_menu_button import GetBotMenuButton
from .set_bot_broadcast_default_admin_rights import SetBotBroadcastDefaultAdminRights
from .set_bot_group_default_admin_rights import SetBotGroupDefaultAdminRights
from .set_bot_info import SetBotInfo
from .get_bot_info import GetBotInfo
from .reorder_usernames import ReorderUsernames
from .toggle_username import ToggleUsername
from .can_send_message import CanSendMessage
from .allow_send_message import AllowSendMessage
from .invoke_web_view_custom_method import InvokeWebViewCustomMethod
