#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from .add_sticker_to_set import AddStickerToSet
from .create_sticker_set import CreateStickerSet
from .get_sticker_set import GetStickerSet

class Stickers(
    AddStickerToSet,
    CreateStickerSet,
    GetStickerSet
):
    pass
