#  FORK PYROFORK <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .create_sticker_set import CreateStickerSet
from .remove_sticker_from_set import RemoveStickerFromSet
from .change_sticker_position import ChangeStickerPosition
from .add_sticker_to_set import AddStickerToSet
from .set_sticker_set_thumb import SetStickerSetThumb
from .check_short_name import CheckShortName
from .suggest_short_name import SuggestShortName
from .change_sticker import ChangeSticker
from .rename_sticker_set import RenameStickerSet
from .delete_sticker_set import DeleteStickerSet
from .replace_sticker import ReplaceSticker
