#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from .input_message_content import InputMessageContent
from .input_reply_to_message import InputReplyToMessage
from .input_reply_to_story import InputReplyToStory
from .input_text_message_content import InputTextMessageContent

__all__ = [
    "InputMessageContent", "InputReplyToMessage", "InputReplyToStory", "InputTextMessageContent"
]
