#  FORK PYROFORK <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .file_unknown import FileUnknown
from .file_partial import FilePartial
from .file_jpeg import FileJpeg
from .file_gif import FileGif
from .file_png import FilePng
from .file_pdf import FilePdf
from .file_mp3 import FileMp3
from .file_mov import FileMov
from .file_mp4 import FileMp4
from .file_webp import FileWebp
